import { IChainable } from 'aws-cdk-lib/aws-stepfunctions';
import { Construct, IConstruct } from 'constructs';
export declare class AppendDelimiter {
    static readonly NEWLINE: AppendDelimiter;
    static readonly PARAGRAPH: AppendDelimiter;
    static of(delimiter: string): AppendDelimiter;
    readonly delimiter: string;
    private constructor();
}
export interface DescriptionBuilderProps {
    readonly initialDescription?: string;
}
export interface DescriptionBuilderIteratorProps {
    readonly arrayRef: string;
    readonly fieldDelimiter?: AppendDelimiter;
    readonly recordDelimiter?: AppendDelimiter;
    readonly resultPath: string;
    readonly sectionDelimiter?: AppendDelimiter;
    readonly title?: string;
}
export interface DescriptionBuilderSectionProps {
    readonly referenceChecks?: string[];
    readonly title: string;
}
export interface AddReferenceProps {
    readonly delimiter?: AppendDelimiter;
    readonly label?: string;
    readonly value: string;
    readonly required?: boolean;
}
export interface SetDelimiterProps {
    readonly delimiter: AppendDelimiter;
}
export interface WriteProps {
    readonly defaultDelimiter?: AppendDelimiter;
    readonly delimiter?: AppendDelimiter;
    readonly prefix?: string;
    readonly value: string;
    readonly required?: boolean;
    readonly suffix?: string;
}
export interface IDelayedChainable {
    render(): IChainable;
}
export interface IDescriptionBuilderComponent extends IDelayedChainable {
    readonly classifier: string;
    addIterator(id: string, props: DescriptionBuilderIteratorProps): DescriptionBuilderIterator;
    addReference(id: string, props: AddReferenceProps): IChainable;
    setDelimiter(id: string, props: SetDelimiterProps): IChainable;
    write(id: string, props: WriteProps): IChainable;
}
declare abstract class DescriptionBuilderBase extends Construct implements IDescriptionBuilderComponent, IDelayedChainable {
    private readonly _chain;
    get classifier(): string;
    constructor(scope: IConstruct, id: string);
    addIterator(id: string, props: DescriptionBuilderIteratorProps): DescriptionBuilderIterator;
    addReference(id: string, props: AddReferenceProps): IChainable;
    protected buildId(prefix: string, id?: string): string;
    private resolveRequired;
    setDelimiter(id: string, props: SetDelimiterProps): IChainable;
    write(id: string, props: WriteProps): IChainable;
    protected registerBuilder(builder: IDescriptionBuilderComponent): IDescriptionBuilderComponent;
    protected registerChainable(chainable: IChainable): IChainable;
    render(): IChainable;
}
export declare class DescriptionBuilderIterator extends DescriptionBuilderBase {
    readonly arrayRef: string;
    readonly fieldDelimiter: AppendDelimiter;
    readonly recordDelimiter: AppendDelimiter;
    readonly resultPath: string;
    readonly sectionDelimiter: AppendDelimiter;
    readonly title?: string;
    constructor(scope: IConstruct, id: string, props: DescriptionBuilderIteratorProps);
    render(): IChainable;
    write(id: string, props: WriteProps): IChainable;
}
export declare class DescriptionBuilderSection extends DescriptionBuilderBase {
    private readonly _refs;
    readonly title: string;
    get refs(): string[];
    constructor(scope: IConstruct, id: string, props: DescriptionBuilderSectionProps);
    addReferenceCheck(ref: string): void;
    render(): IChainable;
}
export declare class DescriptionBuilder extends DescriptionBuilderBase {
    readonly initialDescription: string;
    readonly initializeNode: IChainable;
    constructor(scope: IConstruct, props?: DescriptionBuilderProps);
    addSection(id: string, props: DescriptionBuilderSectionProps): DescriptionBuilderSection;
    protected initialize(): IChainable;
}
export {};
