import { Duration } from 'aws-cdk-lib';
import { Chain, Condition, IStateMachine } from 'aws-cdk-lib/aws-stepfunctions';
import { IConstruct } from 'constructs';
import { IssueParserPluginBase } from './issue-parser-plugin-base';
import { IssueHandlerOverride } from '../issue-handler-override';
import { IssuePluginBaseProps } from '../issue-plugin-base';
import { IssueTrigger } from '../issue-trigger';
export declare class GuardDutySeverity {
    static readonly INFORMATIONAL: GuardDutySeverity;
    static readonly LOW: GuardDutySeverity;
    static readonly MEDIUM: GuardDutySeverity;
    static readonly HIGH: GuardDutySeverity;
    static readonly CRITICAL: GuardDutySeverity;
    static of(standardized: string, lowerBound?: number, upperBound?: number): GuardDutySeverity;
    static all(): GuardDutySeverity[];
    static custom(...levels: GuardDutySeverity[]): GuardDutySeverity[];
    static threshold(level: GuardDutySeverity): GuardDutySeverity[];
    readonly lowerBound?: number;
    readonly standardized: string;
    readonly upperBound?: number;
    private constructor();
    buildCondition(path: string): Condition;
}
export interface GuardDutyFindingRuleOptions {
    readonly overrides?: IssueHandlerOverride[];
    readonly severity?: GuardDutySeverity[];
}
export interface GuardDutyFindingProps extends IssuePluginBaseProps {
}
export declare class GuardDutyFinding extends IssueParserPluginBase {
    static readonly MATCH_TYPE: string;
    static readonly SEVERITIES: GuardDutySeverity[];
    readonly name?: string;
    readonly timeout?: Duration;
    readonly handler: IStateMachine;
    get triggers(): IssueTrigger[];
    constructor(scope: IConstruct, id: string, props?: GuardDutyFindingProps);
    private addAccessKeyDetails;
    private addContainerDetails;
    protected addDefaultTrigger(): IssueTrigger;
    private addEcsClusterDetails;
    private addEksClusterDetails;
    private addInstanceDetails;
    private addKubernetesDetails;
    private addLambdaDetails;
    private addRdsDbInstanceDetails;
    private addS3BucketDetails;
    private addSectionCheck;
    private addSectionHeader;
    addSectionField(id: string, key: string, path: string): Chain;
    bind(_scope: IConstruct): IssueTrigger[];
    protected buildSeverityMap(): Chain;
    registerIssueTrigger(id: string, options?: GuardDutyFindingRuleOptions): IssueTrigger;
}
