import { Duration } from 'aws-cdk-lib';
import { Chain, IStateMachine } from 'aws-cdk-lib/aws-stepfunctions';
import { IConstruct } from 'constructs';
import { IssueHandlerOverride } from '../issue-handler-override';
import { IIssueParser } from '../issue-manager';
import { IssuePluginBase, IssuePluginBaseProps } from '../issue-plugin-base';
import { IssueTrigger } from '../issue-trigger';
export declare class SecurityHubSeverity {
    static readonly INFORMATIONAL: SecurityHubSeverity;
    static readonly LOW: SecurityHubSeverity;
    static readonly MEDIUM: SecurityHubSeverity;
    static readonly HIGH: SecurityHubSeverity;
    static readonly CRITICAL: SecurityHubSeverity;
    static of(name: string, lowerBound: number, upperBound: number, standardized: string): SecurityHubSeverity;
    readonly name: string;
    readonly lowerBound: number;
    readonly standardized: string;
    readonly upperBound: number;
    private constructor();
}
export interface ISecurityHubSeverityConfiguration {
    readonly levels: SecurityHubSeverity[];
}
export declare class SecurityHubSeverityConfiguration {
    static all(): ISecurityHubSeverityConfiguration;
    static custom(...levels: SecurityHubSeverity[]): ISecurityHubSeverityConfiguration;
    static threshold(level: SecurityHubSeverity): ISecurityHubSeverityConfiguration;
}
export interface SecurityHubFindingEventOptions {
    readonly overrides?: IssueHandlerOverride[];
    readonly severity?: ISecurityHubSeverityConfiguration;
}
export interface SecurityHubFindingProps extends IssuePluginBaseProps {
    readonly matchType?: string;
    readonly name?: string;
    readonly timeout?: Duration;
}
export declare class SecurityHubFinding extends IssuePluginBase implements IIssueParser {
    static readonly MATCH_TYPE: string;
    static readonly SEVERITIES: SecurityHubSeverity[];
    readonly name?: string;
    readonly timeout?: Duration;
    readonly handler: IStateMachine;
    readonly matchType: string;
    get triggers(): IssueTrigger[];
    constructor(scope: IConstruct, id: string, props?: SecurityHubFindingProps);
    bind(_scope: IConstruct): IssueTrigger[];
    protected buildDescription(): Chain;
    protected buildRemediation(): Chain;
    protected buildResources(): Chain;
    protected buildSeverityMap(): Chain;
    protected buildUrl(): Chain;
    registerIssueTrigger(id: string, options?: SecurityHubFindingEventOptions): IssueTrigger;
}
