import { Resource, ResourceProps } from 'aws-cdk-lib';
import { ICertificate } from 'aws-cdk-lib/aws-certificatemanager';
import { ClientVpnAuthorizationRule, ClientVpnAuthorizationRuleOptions, ClientVpnEndpoint, ClientVpnUserBasedAuthentication, Connections, IClientVpnConnectionHandler, IClientVpnEndpoint, IConnectable, ISecurityGroup, ISubnet, IVpc, TransportProtocol, VpnPort } from 'aws-cdk-lib/aws-ec2';
import { ILogGroup, ILogStream } from 'aws-cdk-lib/aws-logs';
import { IConstruct, IDependable } from 'constructs';
import { ITransitGateway } from '../ec2';
import { IIpv4CidrAssignment } from '../ec2/lib/cidr-assignment';
import { VpcCidrBlock } from '../ec2/vpc-cidr-block';
export interface AddAuthorizationRuleOptions extends ClientVpnAuthorizationRuleOptions {
    readonly scope?: IConstruct;
}
export interface AddMultiSubnetRouteOptions {
    readonly cidr: string;
    readonly description?: string;
    readonly scope?: IConstruct;
}
export interface NetworkIsolatedClientVpnEndpointProps extends ResourceProps {
    readonly authorizeAllUsersToVpcCidr?: boolean;
    readonly clientCertificate?: ICertificate;
    readonly clientConnectionHandler?: IClientVpnConnectionHandler;
    readonly clientLoginBanner?: string;
    readonly description?: string;
    readonly dnsServers?: string[];
    readonly logGroup?: ILogGroup;
    readonly logStream?: ILogStream;
    readonly logging?: boolean;
    readonly maxAzs?: number;
    readonly port?: VpnPort;
    readonly securityGroups?: ISecurityGroup[];
    readonly selfServicePortal?: boolean;
    readonly serverCertificate: ICertificate;
    readonly splitTunnel?: boolean;
    readonly subnetCidr: IIpv4CidrAssignment;
    readonly transitGateway?: ITransitGateway;
    readonly transportProtocol?: TransportProtocol;
    readonly userBasedAuthentication?: ClientVpnUserBasedAuthentication;
    readonly vpc: IVpc;
    readonly vpnCidr?: IIpv4CidrAssignment;
}
export declare class NetworkIsolatedClientVpnEndpoint extends Resource implements IClientVpnEndpoint, IConnectable {
    static readonly DEFAULT_VPN_CIDR: string;
    private readonly _subnets;
    private _transitGateway?;
    readonly authorizeAllUsersToVpcCidr?: boolean;
    readonly clientCertificate?: ICertificate;
    readonly clientConnectionHandler?: IClientVpnConnectionHandler;
    readonly clientLoginBanner?: string;
    readonly description?: string;
    readonly dnsServers?: string[];
    readonly logGroup?: ILogGroup;
    readonly logStream?: ILogStream;
    readonly logging?: boolean;
    readonly maxAzs: number;
    readonly port?: VpnPort;
    readonly securityGroups?: ISecurityGroup[];
    readonly selfServicePortal?: boolean;
    readonly serverCertificate: ICertificate;
    readonly splitTunnel?: boolean;
    readonly transportProtocol?: TransportProtocol;
    readonly userBasedAuthentication?: ClientVpnUserBasedAuthentication;
    readonly vpc: IVpc;
    readonly vpnCidr: IIpv4CidrAssignment;
    get transitGateway(): ITransitGateway | undefined;
    readonly clientVpnEndpoint: ClientVpnEndpoint;
    readonly vpcCidrBlock: VpcCidrBlock;
    get subnets(): ISubnet[];
    readonly endpointId: string;
    readonly targetNetworksAssociated: IDependable;
    readonly connections: Connections;
    constructor(scope: IConstruct, id: string, props: NetworkIsolatedClientVpnEndpointProps);
    addAuthorizationRule(id: string, options: AddAuthorizationRuleOptions): ClientVpnAuthorizationRule;
    addMultiSubnetRoute(id: string, options: AddMultiSubnetRouteOptions): any;
    registerTransitGateway(transitGateway: ITransitGateway): void;
}
