import { Stack } from 'aws-cdk-lib';
import { IConstruct } from 'constructs';
import { BoundGroupConfiguration, IGroupConfiguration } from './configuration-ref';
export interface IStackReference {
    readonly stackConstruct?: Stack;
    readonly stackId: string;
}
export declare class StackReference {
    static fromStackId(stackId: string): IStackReference;
    static fromStack(stack: Stack): IStackReference;
}
export interface CloudFormationStackProps {
    readonly resourceTypes?: string[];
}
/**
 * Configuration object for a Resource Group whose resources mirror those
 * controlled by a CloudFormation stack.
 */
export declare class CloudFormationStack implements IGroupConfiguration {
    /**
     * Internal collection of resource types that are allowed to be in the
     * Resource Group being configured.
     */
    private readonly _resourceTypes;
    /**
     * The details of the CloudFormation stack that is referenced to create the
     * Resource Group.
     */
    readonly reference: IStackReference;
    /**
     * Collection of resource types that are allowed to be in the Resource Group
     * being configured.
     */
    get resourceTypes(): string[];
    /**
     * Creates a new instance of the CloudFormationStack class.
     *
     * @param reference A reference to a CloudFormation stack that determines the
     * resources to be contained in the Resource Group.
     */
    constructor(reference: IStackReference, props?: CloudFormationStackProps);
    /**
     * Add a resource type to the resource group.
     *
     * If no resource types are registered in the configuration then all resource
     * types are allowed.
     *
     * @param typeId The type that is to be added to the resource group.
     * @returns The Resource Group configuration object to which the type was
     * registered.
     */
    addResourceType(typeId: string): CloudFormationStack;
    /**
     * Associates this configuration with a construct that is handling the
     * creation of a resource group.
     *
     * @param _scope The construct managing the creation of the Resource Group.
     * @returns The configuration to be used for the Resource Group.
     */
    bind(_scope: IConstruct): BoundGroupConfiguration;
}
